@@ -1,7 +1,7 @@
 """
 Type annotations for migration-hub-refactor-spaces service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_migration_hub_refactor_spaces/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migration_hub_refactor_spaces/type_defs/)
 
 Usage::
 
@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
-from typing_extensions import NotRequired
-
 from .literals import (
     ApiGatewayEndpointTypeType,
     ApplicationStateType,
@@ -78,14 +76,19 @@ __all__ = (
     "LambdaEndpointConfigTypeDef",
     "LambdaEndpointInputTypeDef",
     "LambdaEndpointSummaryTypeDef",
+    "ListApplicationsRequestListApplicationsPaginateTypeDef",
     "ListApplicationsRequestRequestTypeDef",
     "ListApplicationsResponseTypeDef",
+    "ListEnvironmentVpcsRequestListEnvironmentVpcsPaginateTypeDef",
     "ListEnvironmentVpcsRequestRequestTypeDef",
     "ListEnvironmentVpcsResponseTypeDef",
+    "ListEnvironmentsRequestListEnvironmentsPaginateTypeDef",
     "ListEnvironmentsRequestRequestTypeDef",
     "ListEnvironmentsResponseTypeDef",
+    "ListRoutesRequestListRoutesPaginateTypeDef",
     "ListRoutesRequestRequestTypeDef",
     "ListRoutesResponseTypeDef",
+    "ListServicesRequestListServicesPaginateTypeDef",
     "ListServicesRequestRequestTypeDef",
     "ListServicesResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -106,69 +109,86 @@ __all__ = (
 ApiGatewayProxyConfigTypeDef = TypedDict(
     "ApiGatewayProxyConfigTypeDef",
     {
-        "ApiGatewayId": NotRequired[str],
-        "EndpointType": NotRequired[ApiGatewayEndpointTypeType],
-        "NlbArn": NotRequired[str],
-        "NlbName": NotRequired[str],
-        "ProxyUrl": NotRequired[str],
-        "StageName": NotRequired[str],
-        "VpcLinkId": NotRequired[str],
+        "ApiGatewayId": str,
+        "EndpointType": ApiGatewayEndpointTypeType,
+        "NlbArn": str,
+        "NlbName": str,
+        "ProxyUrl": str,
+        "StageName": str,
+        "VpcLinkId": str,
     },
+    total=False,
 )
 
 ApiGatewayProxyInputTypeDef = TypedDict(
     "ApiGatewayProxyInputTypeDef",
     {
-        "EndpointType": NotRequired[ApiGatewayEndpointTypeType],
-        "StageName": NotRequired[str],
+        "EndpointType": ApiGatewayEndpointTypeType,
+        "StageName": str,
     },
+    total=False,
 )
 
 ApiGatewayProxySummaryTypeDef = TypedDict(
     "ApiGatewayProxySummaryTypeDef",
     {
-        "ApiGatewayId": NotRequired[str],
-        "EndpointType": NotRequired[ApiGatewayEndpointTypeType],
-        "NlbArn": NotRequired[str],
-        "NlbName": NotRequired[str],
-        "ProxyUrl": NotRequired[str],
-        "StageName": NotRequired[str],
-        "VpcLinkId": NotRequired[str],
+        "ApiGatewayId": str,
+        "EndpointType": ApiGatewayEndpointTypeType,
+        "NlbArn": str,
+        "NlbName": str,
+        "ProxyUrl": str,
+        "StageName": str,
+        "VpcLinkId": str,
     },
+    total=False,
 )
 
 ApplicationSummaryTypeDef = TypedDict(
     "ApplicationSummaryTypeDef",
     {
-        "ApiGatewayProxy": NotRequired["ApiGatewayProxySummaryTypeDef"],
-        "ApplicationId": NotRequired[str],
-        "Arn": NotRequired[str],
-        "CreatedByAccountId": NotRequired[str],
-        "CreatedTime": NotRequired[datetime],
-        "EnvironmentId": NotRequired[str],
-        "Error": NotRequired["ErrorResponseTypeDef"],
-        "LastUpdatedTime": NotRequired[datetime],
-        "Name": NotRequired[str],
-        "OwnerAccountId": NotRequired[str],
-        "ProxyType": NotRequired[Literal["API_GATEWAY"]],
-        "State": NotRequired[ApplicationStateType],
-        "Tags": NotRequired[Dict[str, str]],
-        "VpcId": NotRequired[str],
+        "ApiGatewayProxy": "ApiGatewayProxySummaryTypeDef",
+        "ApplicationId": str,
+        "Arn": str,
+        "CreatedByAccountId": str,
+        "CreatedTime": datetime,
+        "EnvironmentId": str,
+        "Error": "ErrorResponseTypeDef",
+        "LastUpdatedTime": datetime,
+        "Name": str,
+        "OwnerAccountId": str,
+        "ProxyType": Literal["API_GATEWAY"],
+        "State": ApplicationStateType,
+        "Tags": Dict[str, str],
+        "VpcId": str,
     },
+    total=False,
 )
 
-CreateApplicationRequestRequestTypeDef = TypedDict(
-    "CreateApplicationRequestRequestTypeDef",
+_RequiredCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateApplicationRequestRequestTypeDef",
     {
         "EnvironmentIdentifier": str,
         "Name": str,
         "ProxyType": Literal["API_GATEWAY"],
         "VpcId": str,
-        "ApiGatewayProxy": NotRequired["ApiGatewayProxyInputTypeDef"],
-        "ClientToken": NotRequired[str],
-        "Tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateApplicationRequestRequestTypeDef",
+    {
+        "ApiGatewayProxy": "ApiGatewayProxyInputTypeDef",
+        "ClientToken": str,
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateApplicationRequestRequestTypeDef(
+    _RequiredCreateApplicationRequestRequestTypeDef, _OptionalCreateApplicationRequestRequestTypeDef
+):
+    pass
+
 
 CreateApplicationResponseTypeDef = TypedDict(
     "CreateApplicationResponseTypeDef",
@@ -190,16 +210,29 @@ CreateApplicationResponseTypeDef = TypedDict(
     },
 )
 
-CreateEnvironmentRequestRequestTypeDef = TypedDict(
-    "CreateEnvironmentRequestRequestTypeDef",
+_RequiredCreateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateEnvironmentRequestRequestTypeDef",
     {
         "Name": str,
         "NetworkFabricType": Literal["TRANSIT_GATEWAY"],
-        "ClientToken": NotRequired[str],
-        "Description": NotRequired[str],
-        "Tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateEnvironmentRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+        "Description": str,
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateEnvironmentRequestRequestTypeDef(
+    _RequiredCreateEnvironmentRequestRequestTypeDef, _OptionalCreateEnvironmentRequestRequestTypeDef
+):
+    pass
+
 
 CreateEnvironmentResponseTypeDef = TypedDict(
     "CreateEnvironmentResponseTypeDef",
@@ -218,18 +251,31 @@ CreateEnvironmentResponseTypeDef = TypedDict(
     },
 )
 
-CreateRouteRequestRequestTypeDef = TypedDict(
-    "CreateRouteRequestRequestTypeDef",
+_RequiredCreateRouteRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateRouteRequestRequestTypeDef",
     {
         "ApplicationIdentifier": str,
         "EnvironmentIdentifier": str,
         "RouteType": RouteTypeType,
         "ServiceIdentifier": str,
-        "ClientToken": NotRequired[str],
-        "Tags": NotRequired[Mapping[str, str]],
-        "UriPathRoute": NotRequired["UriPathRouteInputTypeDef"],
     },
 )
+_OptionalCreateRouteRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateRouteRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+        "Tags": Mapping[str, str],
+        "UriPathRoute": "UriPathRouteInputTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateRouteRequestRequestTypeDef(
+    _RequiredCreateRouteRequestRequestTypeDef, _OptionalCreateRouteRequestRequestTypeDef
+):
+    pass
+
 
 CreateRouteResponseTypeDef = TypedDict(
     "CreateRouteResponseTypeDef",
@@ -250,21 +296,34 @@ CreateRouteResponseTypeDef = TypedDict(
     },
 )
 
-CreateServiceRequestRequestTypeDef = TypedDict(
-    "CreateServiceRequestRequestTypeDef",
+_RequiredCreateServiceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateServiceRequestRequestTypeDef",
     {
         "ApplicationIdentifier": str,
         "EndpointType": ServiceEndpointTypeType,
         "EnvironmentIdentifier": str,
         "Name": str,
-        "ClientToken": NotRequired[str],
-        "Description": NotRequired[str],
-        "LambdaEndpoint": NotRequired["LambdaEndpointInputTypeDef"],
-        "Tags": NotRequired[Mapping[str, str]],
-        "UrlEndpoint": NotRequired["UrlEndpointInputTypeDef"],
-        "VpcId": NotRequired[str],
     },
 )
+_OptionalCreateServiceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateServiceRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+        "Description": str,
+        "LambdaEndpoint": "LambdaEndpointInputTypeDef",
+        "Tags": Mapping[str, str],
+        "UrlEndpoint": "UrlEndpointInputTypeDef",
+        "VpcId": str,
+    },
+    total=False,
+)
+
+
+class CreateServiceRequestRequestTypeDef(
+    _RequiredCreateServiceRequestRequestTypeDef, _OptionalCreateServiceRequestRequestTypeDef
+):
+    pass
+
 
 CreateServiceResponseTypeDef = TypedDict(
     "CreateServiceResponseTypeDef",
@@ -384,44 +443,47 @@ DeleteServiceResponseTypeDef = TypedDict(
 EnvironmentSummaryTypeDef = TypedDict(
     "EnvironmentSummaryTypeDef",
     {
-        "Arn": NotRequired[str],
-        "CreatedTime": NotRequired[datetime],
-        "Description": NotRequired[str],
-        "EnvironmentId": NotRequired[str],
-        "Error": NotRequired["ErrorResponseTypeDef"],
-        "LastUpdatedTime": NotRequired[datetime],
-        "Name": NotRequired[str],
-        "NetworkFabricType": NotRequired[Literal["TRANSIT_GATEWAY"]],
-        "OwnerAccountId": NotRequired[str],
-        "State": NotRequired[EnvironmentStateType],
-        "Tags": NotRequired[Dict[str, str]],
-        "TransitGatewayId": NotRequired[str],
+        "Arn": str,
+        "CreatedTime": datetime,
+        "Description": str,
+        "EnvironmentId": str,
+        "Error": "ErrorResponseTypeDef",
+        "LastUpdatedTime": datetime,
+        "Name": str,
+        "NetworkFabricType": Literal["TRANSIT_GATEWAY"],
+        "OwnerAccountId": str,
+        "State": EnvironmentStateType,
+        "Tags": Dict[str, str],
+        "TransitGatewayId": str,
     },
+    total=False,
 )
 
 EnvironmentVpcTypeDef = TypedDict(
     "EnvironmentVpcTypeDef",
     {
-        "AccountId": NotRequired[str],
-        "CidrBlocks": NotRequired[List[str]],
-        "CreatedTime": NotRequired[datetime],
-        "EnvironmentId": NotRequired[str],
-        "LastUpdatedTime": NotRequired[datetime],
-        "VpcId": NotRequired[str],
-        "VpcName": NotRequired[str],
+        "AccountId": str,
+        "CidrBlocks": List[str],
+        "CreatedTime": datetime,
+        "EnvironmentId": str,
+        "LastUpdatedTime": datetime,
+        "VpcId": str,
+        "VpcName": str,
     },
+    total=False,
 )
 
 ErrorResponseTypeDef = TypedDict(
     "ErrorResponseTypeDef",
     {
-        "AccountId": NotRequired[str],
-        "AdditionalDetails": NotRequired[Dict[str, str]],
-        "Code": NotRequired[ErrorCodeType],
-        "Message": NotRequired[str],
-        "ResourceIdentifier": NotRequired[str],
-        "ResourceType": NotRequired[ErrorResourceTypeType],
+        "AccountId": str,
+        "AdditionalDetails": Dict[str, str],
+        "Code": ErrorCodeType,
+        "Message": str,
+        "ResourceIdentifier": str,
+        "ResourceType": ErrorResourceTypeType,
     },
+    total=False,
 )
 
 GetApplicationRequestRequestTypeDef = TypedDict(
@@ -563,8 +625,9 @@ GetServiceResponseTypeDef = TypedDict(
 LambdaEndpointConfigTypeDef = TypedDict(
     "LambdaEndpointConfigTypeDef",
     {
-        "Arn": NotRequired[str],
+        "Arn": str,
     },
+    total=False,
 )
 
 LambdaEndpointInputTypeDef = TypedDict(
@@ -577,18 +640,54 @@ LambdaEndpointInputTypeDef = TypedDict(
 LambdaEndpointSummaryTypeDef = TypedDict(
     "LambdaEndpointSummaryTypeDef",
     {
-        "Arn": NotRequired[str],
+        "Arn": str,
     },
+    total=False,
 )
 
-ListApplicationsRequestRequestTypeDef = TypedDict(
-    "ListApplicationsRequestRequestTypeDef",
+_RequiredListApplicationsRequestListApplicationsPaginateTypeDef = TypedDict(
+    "_RequiredListApplicationsRequestListApplicationsPaginateTypeDef",
     {
         "EnvironmentIdentifier": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListApplicationsRequestListApplicationsPaginateTypeDef = TypedDict(
+    "_OptionalListApplicationsRequestListApplicationsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListApplicationsRequestListApplicationsPaginateTypeDef(
+    _RequiredListApplicationsRequestListApplicationsPaginateTypeDef,
+    _OptionalListApplicationsRequestListApplicationsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListApplicationsRequestRequestTypeDef = TypedDict(
+    "_RequiredListApplicationsRequestRequestTypeDef",
+    {
+        "EnvironmentIdentifier": str,
+    },
+)
+_OptionalListApplicationsRequestRequestTypeDef = TypedDict(
+    "_OptionalListApplicationsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListApplicationsRequestRequestTypeDef(
+    _RequiredListApplicationsRequestRequestTypeDef, _OptionalListApplicationsRequestRequestTypeDef
+):
+    pass
+
 
 ListApplicationsResponseTypeDef = TypedDict(
     "ListApplicationsResponseTypeDef",
@@ -599,14 +698,50 @@ ListApplicationsResponseTypeDef = TypedDict(
     },
 )
 
-ListEnvironmentVpcsRequestRequestTypeDef = TypedDict(
-    "ListEnvironmentVpcsRequestRequestTypeDef",
+_RequiredListEnvironmentVpcsRequestListEnvironmentVpcsPaginateTypeDef = TypedDict(
+    "_RequiredListEnvironmentVpcsRequestListEnvironmentVpcsPaginateTypeDef",
     {
         "EnvironmentIdentifier": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListEnvironmentVpcsRequestListEnvironmentVpcsPaginateTypeDef = TypedDict(
+    "_OptionalListEnvironmentVpcsRequestListEnvironmentVpcsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListEnvironmentVpcsRequestListEnvironmentVpcsPaginateTypeDef(
+    _RequiredListEnvironmentVpcsRequestListEnvironmentVpcsPaginateTypeDef,
+    _OptionalListEnvironmentVpcsRequestListEnvironmentVpcsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListEnvironmentVpcsRequestRequestTypeDef = TypedDict(
+    "_RequiredListEnvironmentVpcsRequestRequestTypeDef",
+    {
+        "EnvironmentIdentifier": str,
+    },
+)
+_OptionalListEnvironmentVpcsRequestRequestTypeDef = TypedDict(
+    "_OptionalListEnvironmentVpcsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListEnvironmentVpcsRequestRequestTypeDef(
+    _RequiredListEnvironmentVpcsRequestRequestTypeDef,
+    _OptionalListEnvironmentVpcsRequestRequestTypeDef,
+):
+    pass
+
 
 ListEnvironmentVpcsResponseTypeDef = TypedDict(
     "ListEnvironmentVpcsResponseTypeDef",
@@ -617,12 +752,21 @@ ListEnvironmentVpcsResponseTypeDef = TypedDict(
     },
 )
 
+ListEnvironmentsRequestListEnvironmentsPaginateTypeDef = TypedDict(
+    "ListEnvironmentsRequestListEnvironmentsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListEnvironmentsRequestRequestTypeDef = TypedDict(
     "ListEnvironmentsRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListEnvironmentsResponseTypeDef = TypedDict(
@@ -634,15 +778,51 @@ ListEnvironmentsResponseTypeDef = TypedDict(
     },
 )
 
-ListRoutesRequestRequestTypeDef = TypedDict(
-    "ListRoutesRequestRequestTypeDef",
+_RequiredListRoutesRequestListRoutesPaginateTypeDef = TypedDict(
+    "_RequiredListRoutesRequestListRoutesPaginateTypeDef",
     {
         "ApplicationIdentifier": str,
         "EnvironmentIdentifier": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListRoutesRequestListRoutesPaginateTypeDef = TypedDict(
+    "_OptionalListRoutesRequestListRoutesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListRoutesRequestListRoutesPaginateTypeDef(
+    _RequiredListRoutesRequestListRoutesPaginateTypeDef,
+    _OptionalListRoutesRequestListRoutesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListRoutesRequestRequestTypeDef = TypedDict(
+    "_RequiredListRoutesRequestRequestTypeDef",
+    {
+        "ApplicationIdentifier": str,
+        "EnvironmentIdentifier": str,
+    },
+)
+_OptionalListRoutesRequestRequestTypeDef = TypedDict(
+    "_OptionalListRoutesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListRoutesRequestRequestTypeDef(
+    _RequiredListRoutesRequestRequestTypeDef, _OptionalListRoutesRequestRequestTypeDef
+):
+    pass
+
 
 ListRoutesResponseTypeDef = TypedDict(
     "ListRoutesResponseTypeDef",
@@ -653,15 +833,51 @@ ListRoutesResponseTypeDef = TypedDict(
     },
 )
 
-ListServicesRequestRequestTypeDef = TypedDict(
-    "ListServicesRequestRequestTypeDef",
+_RequiredListServicesRequestListServicesPaginateTypeDef = TypedDict(
+    "_RequiredListServicesRequestListServicesPaginateTypeDef",
     {
         "ApplicationIdentifier": str,
         "EnvironmentIdentifier": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListServicesRequestListServicesPaginateTypeDef = TypedDict(
+    "_OptionalListServicesRequestListServicesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListServicesRequestListServicesPaginateTypeDef(
+    _RequiredListServicesRequestListServicesPaginateTypeDef,
+    _OptionalListServicesRequestListServicesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListServicesRequestRequestTypeDef = TypedDict(
+    "_RequiredListServicesRequestRequestTypeDef",
+    {
+        "ApplicationIdentifier": str,
+        "EnvironmentIdentifier": str,
+    },
+)
+_OptionalListServicesRequestRequestTypeDef = TypedDict(
+    "_OptionalListServicesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListServicesRequestRequestTypeDef(
+    _RequiredListServicesRequestRequestTypeDef, _OptionalListServicesRequestRequestTypeDef
+):
+    pass
+
 
 ListServicesResponseTypeDef = TypedDict(
     "ListServicesResponseTypeDef",
@@ -690,10 +906,11 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PutResourcePolicyRequestRequestTypeDef = TypedDict(
@@ -718,47 +935,49 @@ ResponseMetadataTypeDef = TypedDict(
 RouteSummaryTypeDef = TypedDict(
     "RouteSummaryTypeDef",
     {
-        "ApplicationId": NotRequired[str],
-        "Arn": NotRequired[str],
-        "CreatedByAccountId": NotRequired[str],
-        "CreatedTime": NotRequired[datetime],
-        "EnvironmentId": NotRequired[str],
-        "Error": NotRequired["ErrorResponseTypeDef"],
-        "IncludeChildPaths": NotRequired[bool],
-        "LastUpdatedTime": NotRequired[datetime],
-        "Methods": NotRequired[List[HttpMethodType]],
-        "OwnerAccountId": NotRequired[str],
-        "PathResourceToId": NotRequired[Dict[str, str]],
-        "RouteId": NotRequired[str],
-        "RouteType": NotRequired[RouteTypeType],
-        "ServiceId": NotRequired[str],
-        "SourcePath": NotRequired[str],
-        "State": NotRequired[RouteStateType],
-        "Tags": NotRequired[Dict[str, str]],
+        "ApplicationId": str,
+        "Arn": str,
+        "CreatedByAccountId": str,
+        "CreatedTime": datetime,
+        "EnvironmentId": str,
+        "Error": "ErrorResponseTypeDef",
+        "IncludeChildPaths": bool,
+        "LastUpdatedTime": datetime,
+        "Methods": List[HttpMethodType],
+        "OwnerAccountId": str,
+        "PathResourceToId": Dict[str, str],
+        "RouteId": str,
+        "RouteType": RouteTypeType,
+        "ServiceId": str,
+        "SourcePath": str,
+        "State": RouteStateType,
+        "Tags": Dict[str, str],
     },
+    total=False,
 )
 
 ServiceSummaryTypeDef = TypedDict(
     "ServiceSummaryTypeDef",
     {
-        "ApplicationId": NotRequired[str],
-        "Arn": NotRequired[str],
-        "CreatedByAccountId": NotRequired[str],
-        "CreatedTime": NotRequired[datetime],
-        "Description": NotRequired[str],
-        "EndpointType": NotRequired[ServiceEndpointTypeType],
-        "EnvironmentId": NotRequired[str],
-        "Error": NotRequired["ErrorResponseTypeDef"],
-        "LambdaEndpoint": NotRequired["LambdaEndpointSummaryTypeDef"],
-        "LastUpdatedTime": NotRequired[datetime],
-        "Name": NotRequired[str],
-        "OwnerAccountId": NotRequired[str],
-        "ServiceId": NotRequired[str],
-        "State": NotRequired[ServiceStateType],
-        "Tags": NotRequired[Dict[str, str]],
-        "UrlEndpoint": NotRequired["UrlEndpointSummaryTypeDef"],
-        "VpcId": NotRequired[str],
+        "ApplicationId": str,
+        "Arn": str,
+        "CreatedByAccountId": str,
+        "CreatedTime": datetime,
+        "Description": str,
+        "EndpointType": ServiceEndpointTypeType,
+        "EnvironmentId": str,
+        "Error": "ErrorResponseTypeDef",
+        "LambdaEndpoint": "LambdaEndpointSummaryTypeDef",
+        "LastUpdatedTime": datetime,
+        "Name": str,
+        "OwnerAccountId": str,
+        "ServiceId": str,
+        "State": ServiceStateType,
+        "Tags": Dict[str, str],
+        "UrlEndpoint": "UrlEndpointSummaryTypeDef",
+        "VpcId": str,
     },
+    total=False,
 )
 
 TagResourceRequestRequestTypeDef = TypedDict(
@@ -777,36 +996,62 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UriPathRouteInputTypeDef = TypedDict(
-    "UriPathRouteInputTypeDef",
+_RequiredUriPathRouteInputTypeDef = TypedDict(
+    "_RequiredUriPathRouteInputTypeDef",
     {
         "ActivationState": Literal["ACTIVE"],
         "SourcePath": str,
-        "IncludeChildPaths": NotRequired[bool],
-        "Methods": NotRequired[Sequence[HttpMethodType]],
     },
 )
+_OptionalUriPathRouteInputTypeDef = TypedDict(
+    "_OptionalUriPathRouteInputTypeDef",
+    {
+        "IncludeChildPaths": bool,
+        "Methods": Sequence[HttpMethodType],
+    },
+    total=False,
+)
+
+
+class UriPathRouteInputTypeDef(
+    _RequiredUriPathRouteInputTypeDef, _OptionalUriPathRouteInputTypeDef
+):
+    pass
+
 
 UrlEndpointConfigTypeDef = TypedDict(
     "UrlEndpointConfigTypeDef",
     {
-        "HealthUrl": NotRequired[str],
-        "Url": NotRequired[str],
+        "HealthUrl": str,
+        "Url": str,
     },
+    total=False,
 )
 
-UrlEndpointInputTypeDef = TypedDict(
-    "UrlEndpointInputTypeDef",
+_RequiredUrlEndpointInputTypeDef = TypedDict(
+    "_RequiredUrlEndpointInputTypeDef",
     {
         "Url": str,
-        "HealthUrl": NotRequired[str],
     },
 )
+_OptionalUrlEndpointInputTypeDef = TypedDict(
+    "_OptionalUrlEndpointInputTypeDef",
+    {
+        "HealthUrl": str,
+    },
+    total=False,
+)
+
+
+class UrlEndpointInputTypeDef(_RequiredUrlEndpointInputTypeDef, _OptionalUrlEndpointInputTypeDef):
+    pass
+
 
 UrlEndpointSummaryTypeDef = TypedDict(
     "UrlEndpointSummaryTypeDef",
     {
-        "HealthUrl": NotRequired[str],
-        "Url": NotRequired[str],
+        "HealthUrl": str,
+        "Url": str,
     },
+    total=False,
 )
